python-tldap
============
TLDAP is a high level LDAP library for Python that uses Ecto like models
to define LDAP schemas that can then be used in an easy way from Python code.
It also supports fake LDAP transactions, to try and ensure LDAP database
remains in a consistent state, even if there are errors that cause the
transaction to fail.

Documentation can be found at http://python-tldap.readthedocs.org/
